package Qt::Gui::QStyleOptionViewItemV2;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QStyleOptionViewItemV2
# file     : QtGui/qstyleoption.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QStyleOptionViewItem/;
#our @ISA = qw/Qt::Gui::QStyleOptionViewItem/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QStyleOptionViewItemV2

=head1 PUBLIC METHODS

=over

=item   QStyleOptionViewItemV2()

=item   QStyleOptionViewItemV2(const QStyleOptionViewItemV2 & other)

=item   QStyleOptionViewItemV2(const QStyleOptionViewItem & other)

=item  QStyleOptionViewItemV2 & operator=(const QStyleOptionViewItem & other)


=back

=head1 ENUM VALUES

=over

=item Version

=item None

=item WrapText

=item Alternate

=item HasCheckIndicator

=item HasDisplay

=item HasDecoration


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
